@@ -73,6 +73,7 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         self.ui_root.clicked.connect(self.root_button)
         self.ui_fs.clicked.connect(self.fs_button)
         self.ui_FileList.cellClicked.connect(self.onCellClicked)
+        self.ui_FileList.cellDoubleClicked.connect(self.onCellDoubleClicked)
         self.ui_DirList.currentIndexChanged.connect(self.selection_directory)
 
     def button_icons(self):
@@ -100,11 +101,12 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         self.active_url = self.fs_home_url
         if self.fs:
             self.fs.close()
+        if self.wparm is not None:
+            self.wparm = None
         self.fs = fs.open_fs(self.active_url)
         self.browse_folder()
         self.selection_directory()
 
-
     def fs_button(self):
         """
         Action fs button
@@ -112,6 +114,8 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         self.active_url = self.fs_url
         if self.fs:
             self.fs.close()
+        if self.wparm is not None:
+            self.wparm = None
         self.fs = fs.open_fs(self.active_url)
         self.browse_folder()
         self.selection_directory()
@@ -123,6 +127,8 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         self.active_url = self.fs_root_url
         if self.fs:
             self.fs.close()
+        if self.wparm is not None:
+            self.wparm = None
         self.fs = fs.open_fs(self.active_url)
         self.browse_folder()
         self.selection_directory()
@@ -153,6 +159,7 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         """
         Fills the filenames based on file_type into a FileList, also directories
         """
+        QtWidgets.QApplication.setOverrideCursor(QtCore.Qt.WaitCursor)
         self.selected_dir = self.ui_DirList.currentText()
         self.ui_FileList.clearContents()
         file_type = self.ui_FileType.text()
@@ -170,15 +177,20 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
             _sel_dir = u"."
         else:
             _sel_dir = self.selected_dir
-        for item in sorted(self.fs.listdir(_sel_dir)):
-            _item = fs.path.combine(_sel_dir, item)
+        # don't scan on clear
+        if not _sel_dir == "":
             try:
-                if not self.fs.isdir(_item) and match_extension(item, [file_type]):
-                    self.file_list_items.append(_item)
-                elif self.fs.isdir(_item):
-                    self.dir_list_items.append(_item)
-            except fs.errors.PermissionDenied:
-                logging.info("can't access {}".format(item))
+                 for item in sorted(self.fs.listdir(_sel_dir)):
+                    _item = fs.path.combine(_sel_dir, item)
+                    try:
+                        if not self.fs.isdir(_item) and match_extension(item, [file_type]):
+                            self.file_list_items.append(_item)
+                        elif self.fs.isdir(_item):
+                            self.dir_list_items.append(_item)
+                    except fs.errors.PermissionDenied:
+                        logging.info("can't access {}".format(item))
+            except UnicodeDecodeError as e:
+                logging.error("Error: {}".format(e))
 
         self.ui_FileList.setRowCount(len(self.file_list_items) + len(self.dir_list_items))
         index = 0
@@ -187,14 +199,14 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
             self.ui_FileList.setCellWidget(index, 0, WidgetImageText(fs.path.basename(item), self.dir_icon, item))
             index = index + 1
         for item in self.file_list_items:
-            self.ui_FileList.setCellWidget(index, 0, WidgetImageText(fs.path.basename(item), self.file_icon, item ))
+            self.ui_FileList.setCellWidget(index, 0, WidgetImageText(fs.path.basename(item), self.file_icon, item))
             index = index + 1
         if self.last_index == 0 and not self.show_save_action:
             self.ui_FileList.clearSelection()
             if self.ui_FileList.currentItem() is not None:
                 self.ui_SelectedName.setText(self.ui_FileList.currentItem().text())
         self.ui_FileList.resizeRowsToContents()
-
+        QtWidgets.QApplication.restoreOverrideCursor()
 
     @QtCore.pyqtSlot(int, int)
     def onCellClicked(self, row, column):
@@ -207,11 +219,19 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         if self.wparm is not None:
             if "text" in self.wparm.img:
                 self.ui_SelectedName.setText(self.wparm.text)
+
+    @QtCore.pyqtSlot(int, int)
+    def onCellDoubleClicked(self, row, column):
+        """
+        Action for ui_FileList WidgetImageText on doubleclick
+        :param row: position
+        :param column: position
+        """
+        self.wparm = self.ui_FileList.cellWidget(row, column)
+        if self.wparm is not None:
             if "folder" in self.wparm.img:
                 index = self.dir_list_items.index(self.wparm.value) + 1
                 if index != 0:
-                    self.ui_DirList.setCurrentIndex(index)
-                    self.selection_directory()
                     self.browse_folder(subdir=self.wparm.value)
 
     def selection_file_type(self):
@@ -291,10 +311,7 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         if ok:
             dirname = u''
             if self.wparm is not None:
-                if self.wparm.value == './{}'.format(self.wparm.text):
-                    dirname = self.wparm.value
-                else:
-                    dirname = fs.path.dirname(self.wparm.value)
+                dirname = self.wparm.value
             new_dir = fs.path.combine(dirname, new_dir_name)
             if not self.fs.isdir(new_dir):
                 self.fs.makedir(new_dir)
